@@ -4,7 +4,7 @@
 
 #' Get vegetation data from a local NASIS Database
 #' 
-#' Get veg data from a local NASIS Database.
+#' Get vegetation data from a local NASIS Database. Result includes two data.frames corresponding to the "Plot Plant Inventory" and "Vegetation Transect" child tables of "Vegetation Plot".
 #' 
 #' @param SS get data from the currently loaded Selected Set in NASIS or from
 #' the entire local database (default: `TRUE`)
@@ -12,7 +12,7 @@
 #' @param dsn Optional: path to local SQLite database containing NASIS
 #' table structure; default: `NULL`
 #' 
-#' @return A list with the results.
+#' @return A list of data.frame 
 #' @author Jay M. Skovlin and Dylan E. Beaudette
 #' @keywords manip
 #' @examples
@@ -30,38 +30,23 @@
 #' @export get_veg_data_from_NASIS_db
 get_veg_data_from_NASIS_db <- function(SS=TRUE, dsn = NULL) {
 
-# warning to use NASIS query to load related vegplot data for this to work
-warning("In order to query this data you'll need to load all related vegplots to your sites and pedons in NASIS.", call. = FALSE)
-
-  ## does this require tables that standard site/pedons queries don't hit?
-  # https://github.com/ncss-tech/soilDB/issues/49
   # existing veg
-  q.veg <- "SELECT siteiid, vegplotid, vegplotname, obsdate, primarydatacollector, datacollectionpurpose, assocuserpedonid, ppi.seqnum, plantsym, plantsciname, plantnatvernm, orderofdominance, speciescancovpct, speciescancovclass
-
+  # NOTE: left join of siteobs:vegplot ensures that all site/siteobs are in this result, 
+  #       records will be NA filled when no vegplot available
+  q.veg <- "SELECT siteiid, vegplotiid, vegplotid, vegplotname, obsdate, primarydatacollector, datacollectionpurpose, assocuserpedonid, ppi.seqnum, plantsym, plantsciname, plantnatvernm, orderofdominance, speciescancovpct, speciescancovclass
   FROM site_View_1 AS s
   INNER JOIN siteobs_View_1 AS so ON so.siteiidref = s.siteiid
   LEFT JOIN vegplot_View_1 AS v on v.siteobsiidref = so.siteobsiid
   LEFT JOIN plotplantinventory_View_1 AS ppi ON ppi.vegplotiidref = v.vegplotiid
-  -- note: plant table not managed by SS
   LEFT OUTER JOIN plant ON plant.plantiid = ppi.plantiidref;"
 
   # toggle selected set vs. local DB
-  if(SS == FALSE) {
+  if (SS == FALSE) {
     q.veg <- gsub(pattern = '_View_1', replacement = '', x = q.veg, fixed = TRUE)
   }
-
-  # existing veg
-  #q.inventory <- "SELECT siteiid, vegplotid, vegplotname, obsdate, primarydatacollector, datacollectionpurpose, assocuserpedonid, #plotplantinventory.seqnum, plantsym, plantsciname, plantnatvernm, orderofdominance, speciescancovpct, speciescancovclass
-  #
-  #  FROM site_View_1 AS s
-  #  INNER JOIN siteobs ON siteobs.siteiidref=s.siteiid
-  #  LEFT JOIN vegplot_View_1 AS v on v.siteobsiidref=siteobs.siteobsiid
-  #  LEFT JOIN plotplantinventory ON plotplantinventory.vegplotiidref=v.vegplotiid
-  #  INNER JOIN plant ON plant.plantiid=plotplantinventory.plantiidref
-  #  ORDER BY s.siteiid, plotplantinventory.seqnum;"
   
-  # existing veg
-  q.vegtransect <- "SELECT siteiid, vegplotid, vegplotname, obsdate, primarydatacollector, datacollectionpurpose, assocuserpedonid, vegtransectid, vegtransplantsummiid vtpsiid, transectlength, plantsym, plantsciname, plantnatvernm
+  # veg transect
+  q.vegtransect <- "SELECT siteiid, vegplotiid, vegplotid, vegplotname, obsdate, primarydatacollector, datacollectionpurpose, assocuserpedonid, vegtransectid, vegtransplantsummiid vtpsiid, transectlength, plantsym, plantsciname, plantnatvernm
   
     FROM site_View_1 AS s
     INNER JOIN siteobs ON siteobs.siteiidref=s.siteiid
@@ -76,13 +61,10 @@ warning("In order to query this data you'll need to load all related vegplots to
     q.vegtransect <- gsub(pattern = '_View_1', replacement = '', x = q.vegtransect, fixed = TRUE)
   }
   
-  #q.plant <- "SELECT plantiid, plantsym
-  #  FROM plant_View_1;"
-  
   channel <- dbConnectNASIS(dsn)
   
   if (inherits(channel, 'try-error'))
-    return(data.frame())
+    return(list(veg = data.frame(), vegtransect = data.frame()))
   
   # exec queries
   d.veg <-  dbQueryNASIS(channel, q.veg, close = FALSE)  
